@@ -1,5 +1,6 @@
 import copy
 import inspect
+from os import replace
 from matplotlib.pyplot import title
 import pandas as pd
 import numpy as np
@@ -34,9 +35,14 @@ def inherit_docstrings(cls):
 class MLFrame(pd.DataFrame):
     """A pd.DataFrame with an inplace model, and LinearRegression
     modeling functions.
-    
-    **See pandas.DataFrame documentation"""
+
+        See pandas.DataFrame documentation
+    https://pandas.pydata.org/pandas-docs/stable/reference/api/pandas.DataFrame.html
+    """
+
     model = None
+    """[statsmodels.regression.linear_model.OLS]
+        https://www.statsmodels.org/stable/generated/statsmodels.regression.linear_model.OLS.html#statsmodels.regression.linear_model.OLS"""
 
     def __init__(self, frame, **kwargs):
         super(MLFrame, self).__init__(frame, **kwargs)
@@ -50,22 +56,19 @@ class MLFrame(pd.DataFrame):
         return list(self.select_dtypes('number').columns)
 
     @staticmethod
-    def replace_all(string):
+    def replace_all(string, replace_numbers=False):
         """Replaces bad characters in a string for
-        column names to work in a R~formula"""
-        return string.replace(
+        column names to work in a R~formula
+        
+        Parameters
+        ----------------------------------------
+        replace_numbers[bool]:: Whether to replace numbers with their
+        english counterpart i.e (1 -> one)
+        """
+        string = string.replace(
                       ' ', '_').replace(
                       '(', '').replace(
                       ')', '').replace(
-                    #   '1', 'one').replace(
-                    #   '2', 'two').replace(
-                    #   '3', 'three').replace(
-                    #   '4', 'four').replace(
-                    #   '5', 'five').replace(
-                    #   '6', 'six').replace(
-                    #   '7', 'seven').replace(
-                    #   '8', 'eight').replace(
-                    #   '9', 'nine').replace(
                       '.', '_').replace(
                       '-', '_').replace(
                       '/', '_').replace(
@@ -73,6 +76,18 @@ class MLFrame(pd.DataFrame):
                       '+', '_').replace(
                       ' ', '_').replace(
                       ' ', '_')
+        if replace_numbers:
+            string = string.replace(
+                      '1', 'one').replace(
+                      '2', 'two').replace(
+                      '3', 'three').replace(
+                      '4', 'four').replace(
+                      '5', 'five').replace(
+                      '6', 'six').replace(
+                      '7', 'seven').replace(
+                      '8', 'eight').replace(
+                      '9', 'nine')
+        return string
 
     def clean_col_names(self,
                         inplace=False,
@@ -215,6 +230,7 @@ class MLFrame(pd.DataFrame):
 
     def log(self, columns, inplace=False, verbose=True):
         """ logs the listed columns of the dataframe
+
         Parameters
         ----------------------------------------
         columns[list, str]::
@@ -268,6 +284,7 @@ class MLFrame(pd.DataFrame):
 
     def scale(self, columns, inplace=False, verbose=True):
         """ Scales the listed columns of the dataframe
+
         Parameters
         ----------------------------------------
         columns[list, str]::
@@ -344,11 +361,11 @@ class MLFrame(pd.DataFrame):
     
     @wrapper
     def wrap__getitem__(self, df):
+        """Wrapper for get item [] so that it returns an
+        MLFrame rather then a pd.DataFrame"""
         return df
 
     def __getitem__(self, key):
-        """Wrapper for get item [] so that it returns an
-        MLFrame rather then a pd.DataFrame"""
         call = super().__getitem__(key)
         if isinstance(call, pd.DataFrame):
             return self.wrap__getitem__(call)
@@ -1055,6 +1072,7 @@ class MLFrame(pd.DataFrame):
 
     def distplot(self, target, **kwargs):
         """Plots a seaborn displot of target
+
         Parameters
         ----------------------------------------
         target[str]::
@@ -1079,6 +1097,7 @@ class MLFrame(pd.DataFrame):
 
     def jointplot(self, x, target, **kwargs):
         """Plots a seaborn jointplot of x and target
+
         Parameters
         ----------------------------------------
         x[str]::
@@ -1103,6 +1122,7 @@ class MLFrame(pd.DataFrame):
 
     def boxplot(self, target, **kwargs):
         """Plots a seaborn boxplot of target
+
         Parameters
         ----------------------------------------
         target[str]::
@@ -1152,6 +1172,8 @@ class MLFrame(pd.DataFrame):
                          seed=42,
                          verbose=True):
         """
+        Runs a train test split algorithm on the data
+
         Parameters
         ----------------------------------------
         target[str]::
